#!/bin/bash -l

# Get some variables provided by autosubmit.
WORKDIR=%HPCROOTDIR%
ICON_VERSION=%ICON_VERSION%

BGRID_GLOBAL=%simulation.BGRID_GLOBAL%
RGRID_GLOBAL=%simulation.RGRID_GLOBAL%
BGRID=%simulation.BGRID%
RGRID=%simulation.RGRID%
BEXTPAR=%simulation.BEXTPAR%



STARTDATE=%SDATE%

# Example of date format "2018-06-01T00:00:00Z"
START_YEAR=%Chunk_START_YEAR%
START_MONTH=%Chunk_START_MONTH%
START_DAY=%Chunk_START_DAY%
START_HOUR=%Chunk_START_HOUR%

END_YEAR=%Chunk_END_YEAR%
END_MONTH=%Chunk_END_MONTH%
END_DAY=%Chunk_END_DAY%
END_HOUR=%Chunk_END_HOUR%

Chunk_START_DATE="${START_YEAR}-${START_MONTH}-${START_DAY}T${START_HOUR}:00:00Z"
Chunk_END_DATE="${END_YEAR}-${END_MONTH}-${END_DAY}T${END_HOUR}:00:00Z"

# Convert dates to Unix timestamps
t1_unix=$(date -d "$Chunk_START_DATE" +%s)
t2_unix=$(date -d "$Chunk_END_DATE" +%s)

# Compute difference in seconds
checkpoint_time=$(((t2_unix - t1_unix)))

# Compute number of steps
dtime=180
nsteps=$((checkpoint_time / ${dtime}))

# Extend chunk 10 minutes to ensure checkpoint creation at the proper time
# TODO: Works but it is a bit ugly.
Chunk_END_DATE="${END_YEAR}-${END_MONTH}-${END_DAY}T${END_HOUR}:10:00Z"

MEMBER=%MEMBER%
CHUNK=%CHUNK%

# If the chunk is not the first one, start from a restart file.
if [[ "${CHUNK}" -eq "1" ]]; then
  is_restart=.false.
else
  is_restart=.true.
fi

# Define rundir
RUNDIR=${WORKDIR}/${STARTDATE}/${MEMBER}

cd ${RUNDIR}

# Get AN and FG file names from file that was saved during prepare_rundir
AN_FILE=$( cat an_file.txt )
FG_FILE=$( cat fg_file.txt )


# cat >icon_master.namelist <<EOF
# &master_nml
#     lrestart                    = ${is_restart}
#     lrestart_write_last         = .true.
# /

# &master_model_nml
#     model_type =                1                       ! atmospheric model
#     model_name =                "ATMO"                  ! name of this model component
#     model_namelist_filename =   "icon_atmosphere.namelist"
# /

# &master_time_control_nml
#     calendar                    = "proleptic gregorian"
#     experimentStartDate         = '${Chunk_START_DATE}'
#     experimentStopDate          = '${Chunk_END_DATE}'
# /
# EOF

# cat >icon_atmosphere.namelist <<EOF
# &run_nml
#     ltestcase                   = .TRUE.        ! idealized testcase runs
#     dtime                       = 300           ! time step of 300 seconds
#     output                      = 'nml'         ! use output nameslists
#     msg_level                   = 15
#     nsteps                      = ${nsteps}
#     num_lev                     = 31
#     lvert_nest                  = .false.
#     ldynamics                   = .true.
#     ltransport                  = .true.
#     ntracer                     = 5
#     iforcing                    = 3
# /

# &time_nml
# dt_restart = ${checkpoint_time}
# /

# &io_nml
#   dt_checkpoint            =  ${checkpoint_time}
# /

# &grid_nml
#     dynamics_grid_filename      = '$BGRID_GLOBAL'
#     radiation_grid_filename     = '$RGRID_GLOBAL'
#     dynamics_parent_grid_id     = 0
#     lredgrid_phys               = .true.
# /

# &nh_testcase_nml
#     nh_test_name                = 'APE_nwp'   ! testcase selection
#     ape_sst_case                = 'sst_qobs'
# /

# &nonhydrostatic_nml
#     damp_height                 = 18000
#     rayleigh_coeff              = 0.75
# /

# &nwp_phy_nml
#     inwp_surface                = 0
# /

# &parallel_nml
#     nproma                      = 16
# /

# ! the following two output files are used to initialize the next run
# &output_nml
#     file_interval               = 'PT3600S'
#     output_start                = '${Chunk_START_DATE}'
#     output_end                  = '${Chunk_END_DATE}'
#     output_filename             = "init-test"
#     output_interval             = 'PT3600S'
#     include_last                = .true.
#     mode                        = 1
#     taxis_tunit                 = 1
#     ml_varlist                  = 'group:dwd_fg_atm_vars', 'group:dwd_fg_sfc_vars'
#     remap                       = 1
#     reg_lon_def                 = -30.,0.5,30.
#     reg_lat_def                 = 90.,-0.5, -90.
# /
# &output_nml
#     steps_per_file              = 1
#     output_start                = '${Chunk_START_DATE}'
#     output_end                  = '${Chunk_START_DATE}'
#     output_filename             = "init-test-ext"
#     include_last                = .true.
#     output_interval             = 'PT3600S'
#     ml_varlist                  = 'depth_lk', 'emis_rad', 'fr_lake', 'fr_land', 'topography_c', 'soiltyp', 'sso_stdh', 'sso_theta', 'sso_gamma', 'sso_sigma'
# /
# EOF


# TODO: The namelist shouldn't be hardcoded into the template files.
cat > icon_atmosphere.namelist << EOF
&run_nml
    ltestcase                   = .false.
    dtime                       =  ${dtime}
    output                      = 'nml'
    msg_level                   = 15
    num_lev                     = 90
    lvert_nest                  = .false.
    ldynamics                   = .true.
    ltransport                  = .true.
    ntracer                     = 5
    iforcing                    = 3
/

&time_nml
    dt_restart = ${checkpoint_time}
/

&io_nml
    dt_checkpoint = ${checkpoint_time}
/

&nwp_phy_nml
    lupatmo_phy = .FALSE.
/

&grid_nml
    dynamics_parent_grid_id     = 0
    dynamics_grid_filename      = '$BGRID'
    radiation_grid_filename     = '$RGRID'
    lredgrid_phys               = .true.
/

&extpar_nml
    itopo                       = 1
    extpar_filename             = '$BEXTPAR'
/

&initicon_nml
    init_mode                   = 1,
    dwdfg_filename              = '$FG_FILE'
    dwdana_filename             = '$AN_FILE'
    lconsistency_checks         = .false.
    ana_varnames_map_file       = 'ana_varnames_map_file.txt'
/

! settings from operational setup for vertical coordinate
&sleve_nml
    min_lay_thckn               = 20.
    max_lay_thckn               = 400.
    htop_thcknlimit             = 14000.
    top_height                  = 75000.
    stretch_fac                 = 0.9
    decay_scale_1               = 4000.
    decay_scale_2               = 2500.
    decay_exp                   = 1.2
    flat_height                 = 16000.
/

&nonhydrostatic_nml
    damp_height                 = 22000.
    rayleigh_coeff              = 1
/


&parallel_nml
    nproma                      = 16
/

! LATBC files, these files will be used as input for the next example.
&output_nml
    file_interval               = 'PT3600S'
    output_start                = '${Chunk_START_DATE}'
    output_end                  = '${Chunk_END_DATE}'
    output_filename             = "latbc"
    output_interval             = 'PT3600S'
    include_last                = .true.
    ml_varlist                  = 'u', 'v', 'w', 'theta_v', 'rho', 'qv', 'qc', 'qi', 'qr', 'qs', 'z_ifc'
/

! First Guess file
&output_nml
    file_interval               = 'PT3600S'
    output_start                = '${Chunk_START_DATE}'
    output_end                  = '${Chunk_END_DATE}'
    output_filename             = "init"
    output_interval             = 'PT3600S'
    include_last                = .true.
    ml_varlist                  = 'group:dwd_fg_atm_vars', 'group:dwd_fg_sfc_vars'
/
EOF


cat > icon_master.namelist << EOF
&master_nml
    lrestart                    = ${is_restart}
    lrestart_write_last         = .true.
/

&master_model_nml
    model_type =                1                       ! atmospheric model
    model_name =                "ATMO"                  ! name of this model component
    model_namelist_filename =   "icon_atmosphere.namelist"
/

&master_time_control_nml
    calendar                    = "proleptic gregorian"
    experimentStartDate         = '${Chunk_START_DATE}'
    experimentStopDate          = '${Chunk_END_DATE}'
/
EOF
