#!/bin/bash -l

# Get some variables provided by autosubmit.
WORKDIR=%HPCROOTDIR%
ICON_VERSION=%ICON_VERSION%

BGRID_GLOBAL=%simulation.BGRID_GLOBAL%
RGRID_GLOBAL=%simulation.RGRID_GLOBAL%
BGRID=%simulation.BGRID%
RGRID=%simulation.RGRID%
BEXTPAR=%simulation.BEXTPAR%


# Activate spack
SPACK_ENV=${WORKDIR}/spack/share/spack/setup-env.sh
source ${SPACK_ENV}

# Load icon module needed to retrieve some data
spack load icon-nwp@%ICON_VERSION%

# Create a folder for the common inidata and go there
COMMON_INIDATA_FOLDER=${WORKDIR}/inidata
mkdir -p "${COMMON_INIDATA_FOLDER}"
cd "${COMMON_INIDATA_FOLDER}" || exit

# Download or copy required input files
function download_file() {
  URL=$1
  FILE=${2:-$(basename $URL)}
  if [ ! -e $FILE ]; then
    echo "Download $URL => $FILE"
    wget -q $URL -O $FILE
  fi
}

# Download grid files and external parameters
BASEURL=http://icon-downloads.mpimet.mpg.de/grids/public/edzw
download_file $BASEURL/$BGRID
download_file $BASEURL/$RGRID
download_file $BASEURL/$BEXTPAR

# Link input for radiation
ln -sf "${ICON_DATA_PATH}/rrtmg_lw.nc" .
ln -sf "${ICON_DATA_PATH}/ECHAM6_CldOptProps.nc" .
ln -sf "${ICON_BASE_PATH}/run/ana_varnames_map_file.txt" .


# Set all permissions to read only
chmod -R 640 .